@@ -2,14 +2,14 @@
 '''AlazarTech Package Registration Script
 
 Usage:
-  register [--dev] [--dry-run] [-p <password>] <specfile> <base_url> <version>
+  register [--dev] [--dry-run] [-p <passfile>] <specfile> <base_url> <version>
   register -h | --help
   register --version
 
 Options:
   -h --help      Show this screen
-  -p <password>  If a password should be registered with the website, you can
-                 give it here.
+  -p <passfile>  If a password should be registered with the website, you can
+                 give the file containing the password here.
   --dev          Register packages specified with the development website,
                  instead of the release version.
   --dry-run      Performs a practice run of the operation, without actually
@@ -180,7 +180,7 @@ def payload_from_packages(packages, base_url, version, password):
     return json.dumps(payload)
 
 
-def register(development, password, specsfile, baseurl, version, dry_run):
+def register(development, passfile, specsfile, baseurl, version, dry_run):
     specs = get_specs_from_file(specsfile)
     files = [thing for spec in specs for thing in get_things(spec)]
     packages = packages_from_files(files)
@@ -188,6 +188,10 @@ def register(development, password, specsfile, baseurl, version, dry_run):
         endpoint = "https://dev.alazartech.com/go/to/the/dci/password-file-update/"
     else:
         endpoint = "https://alazartech.com/go/to/the/dci/password-file-update/"
+    password = None
+    if passfile:
+        with open(passfile, 'r') as passf:
+            password = passf.readline().strip()
     payload = payload_from_packages(packages, baseurl, version, password)
     if dry_run:
         print("Dry run, stopping here. The POST request would have been run with:")
@@ -206,7 +210,7 @@ def main():
     '''Main function'''
     arguments = docopt(__doc__, version='Deloy Utility')
     register(development=arguments['--dev'],
-             password=arguments['-p'],
+             passfile=arguments['-p'],
              specsfile=arguments['<specfile>'],
              baseurl=arguments['<base_url>'],
              version=arguments['<version>'],
